@@ -1,11 +1,8 @@
 import requests as http
-import json
 
 
 class openvkapi:
 
-    """Авторизация пользователя"""
-
     @staticmethod
     def auth(login='', password='', code=0, instance='openvk.su', token=''):
         if token == '':
